window.Gleam.initSearch([{"doc":"simple_pubsub","title":"simple_pubsub","content":"# Simple PubSub for gleam\r\n\r\nSimple PubSub for gleam, based on\r\n[process groups](https://hex.pm/packages/process_groups).\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/pubsub)](https://hex.pm/packages/simple_pubsub)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/simple_pubsub/)\r\n\r\n## Usage\r\n\r\nAdd this  library to your Gleam project\r\n\r\n```sh\r\ngleam add simple_pubsub\r\n```\r\n\r\nAnd use it in your project\r\n\r\n## Example\r\n\r\n```gleam\r\nimport simple_pubsub as ps\r\nimport process_groups\r\nimport gleam/erlang/process\r\n\r\n// Messages we want to send over the PubSub\r\ntype PubSubMessage{\r\n    PubSubMessage\r\n}\r\n\r\npub fn main() {\r\n    // start process groups, needed for pubsub\r\n    process_groups.start_link()\r\n\r\n    // create a pubsub\r\n    let pubsub = ps.new_pubsub()\r\n\r\n    // subscribe, normally you would subscribe another process than this one\r\n    let subscription = ps.subscribe(pubsub, process.self())\r\n\r\n    // broadcast a message\r\n    ps.broadcast(pubsub, PubSubMessage)\r\n\r\n    // receive the message\r\n    let assert Ok(PubSubMessage) = ps.receive(subscription, 100)\r\n}\r\n```\r\n## Development\r\n\r\n```sh\r\ngleam run   # Run the project\r\ngleam test  # Run the tests\r\ngleam shell # Run an Erlang shell\r\n```\r\n","url":"index.html"},{"doc":"simple_pubsub","title":"PubSub","content":"pub type PubSub(message) {\n  PubSub(tag: erlang.Reference)\n}\n A pubsub, where process can subscribe and anyone can broadcast\nPubSub(tag: erlang.Reference)\n\n\nSynonyms:\nsimple_pubsub.PubSub\nsimple_pubsub PubSub","url":"simple_pubsub.html#PubSub"},{"doc":"simple_pubsub","title":"Subscription","content":"pub type Subscription(message) {\n  Subscription(pubsub: PubSub(message), owner: process.Pid)\n}\n A Subscription is crated by subscribing to a PubSub\n and can be used to receive broadcast messages on the\n owning thread.\nSubscription(pubsub: PubSub(message), owner: process.Pid)\n\n\nSynonyms:\nsimple_pubsub.Subscription\nsimple_pubsub Subscription","url":"simple_pubsub.html#Subscription"},{"doc":"simple_pubsub","title":"broadcast","content":"pub fn broadcast(pubsub: PubSub(a), msg: a) -&gt; Nil\n Send a message to all processes, subscribed to the PubSub\nSynonyms:\nsimple_pubsub.broadcast\nsimple_pubsub broadcast","url":"simple_pubsub.html#broadcast"},{"doc":"simple_pubsub","title":"demonitor","content":"pub fn demonitor(pubsub: PubSub(a)) -&gt; Bool\n Stop monitoring a PubSub.\nSynonyms:\nsimple_pubsub.demonitor\nsimple_pubsub demonitor","url":"simple_pubsub.html#demonitor"},{"doc":"simple_pubsub","title":"monitor","content":"pub fn monitor(\n  pubsub: PubSub(a),\n) -&gt; #(GroupMonitor(Reference), List(Pid))\n Monitor a PubSub. A `pg.GorupMonitor` event will be \n send, when a process subscribes or unsubscribes.\nSynonyms:\nsimple_pubsub.monitor\nsimple_pubsub monitor","url":"simple_pubsub.html#monitor"},{"doc":"simple_pubsub","title":"new_pubsub","content":"pub fn new_pubsub() -&gt; PubSub(a)\n Create a new pubsub\nSynonyms:\nsimple_pubsub.new_pubsub\nsimple_pubsub new_pubsub","url":"simple_pubsub.html#new_pubsub"},{"doc":"simple_pubsub","title":"receive","content":"pub fn receive(\n  from subject: Subscription(a),\n  within milliseconds: Int,\n) -&gt; Result(a, Nil)\n Receive a message on a subscription.\n has to be done on the process owning the Subscription,\n which is passed to subscribe\nSynonyms:\nsimple_pubsub.receive\nsimple_pubsub receive","url":"simple_pubsub.html#receive"},{"doc":"simple_pubsub","title":"selecting_pubsub_subject","content":"pub fn selecting_pubsub_subject(\n  selector: Selector(a),\n  subject: Subscription(b),\n  handler: fn(b) -&gt; a,\n) -&gt; Selector(a)\n Create a Selector for receiving PubSub messages.\nSynonyms:\nsimple_pubsub.selecting_pubsub_subject\nsimple_pubsub selecting_pubsub_subject","url":"simple_pubsub.html#selecting_pubsub_subject"},{"doc":"simple_pubsub","title":"subscribe","content":"pub fn subscribe(pubsub: PubSub(a), pid: Pid) -&gt; Subscription(a)\n Subscribe a process to a PubSub.\nSynonyms:\nsimple_pubsub.subscribe\nsimple_pubsub subscribe","url":"simple_pubsub.html#subscribe"},{"doc":"simple_pubsub","title":"unsubscribe","content":"pub fn unsubscribe(\n  subscription: Subscription(a),\n  pid: Pid,\n) -&gt; Nil\n Unsubsribe a process from a PubSub.\nSynonyms:\nsimple_pubsub.unsubscribe\nsimple_pubsub unsubscribe","url":"simple_pubsub.html#unsubscribe"},{"doc":"simple_pubsub","title":"simple_pubsub","content":"","url":"simple_pubsub.html"}]);